#ifndef INC_WIDGETS_XLCM_H
#define INC_WIDGETS_XLCM_H

#include <gtk/gtk.h>

#include "widgets_cmn.h"

void widgets_init();

void widgets_load_wdg_activity();
void widgets_load_wdg_messages();
void widgets_load_wdg_popup();

extern GtkWidget *wnd_activity;
extern GtkWidget *wnd_messages;
extern GtkMenu * mn_popup;

struct twdg_activity
{
	GtkProgressBar * prg_up;
	GtkProgressBar * prg_down;
	GtkLabel * lb_msg;
	gboolean realized;
};
extern struct twdg_activity * wdg_activity;

struct twdg_messages
{
	GtkCList * cl_msg_messages;
	GtkButton * bt_msg_clear;
	GtkButton * bt_msg_close;
	gboolean realized;
	GList * msgs;
};
struct tmsg
{
	gchar * row[2];
};
extern struct twdg_messages * wdg_messages;

struct twdg_popup
{
	gboolean realized;
};
extern struct twdg_popup * wdg_popup;

#endif
